'''
@@TODO
<notification participant="201222980047@s.whatsapp.net" t="1419109838" from="201222980047-1330796006@g.us" offline="0" type="w:gp2" id="1804809895" notify="Karim Selima">
<add>
LIST:
<participant jid="4915208759257@s.whatsapp.net">
</participant>
</add>
</notification>

<notification from="4915225256022-1420612467@g.us" notify="Tarek Galal" participant="4915225256022@s.whatsapp.net" id="3484651845" t="1420612534" type="w:gp2">
<add>
LIST:
<participant jid="4915731870097@s.whatsapp.net">
</participant>
</add>
</notification>



'''